# add.pl: main routine for dcbib-add(1).
# $Id: add.pl,v 1.3 1999/05/18 12:47:51 toyoda Exp $
# Copyright (c) TOYODA Eizi, 1998.  All rights reserved.
# see COPYING.TXT for terms of license.

	$ETCDIR = '/etc' unless $ETCDIR;
	$CONFIGFILE = "$ETCDIR/dcbib.conf";

while ($_ = shift) {
	/^-c$/ && ($CONFIGFILE = shift, next);
	&die("undefined commandline argument $_");
}
	
	&emlOpenFile($CONFIGFILE);
	%CONFIG = &emlRead;

	&emlSetFile("STDIN");
	%HEADER = &emlRead();

	&testCard(\%HEADER);

	$outfnam = &generateFileName;
	&creat($outfnam);
	&emlWrite($outfnam, %HEADER);
	print $outfnam "\n";
	while (<STDIN>) {
		print $outfnam $_;
	}
	
	&okay($outfnam);
	&exit;
